@@ -122,6 +122,7 @@ func (cli Cli) Run(args []string) int {
 	flags.BoolVar(&inFlag.CSV, "icsv", false, "CSV format for input.")
 	flags.BoolVar(&inFlag.LTSV, "iltsv", false, "LTSV format for input.")
 	flags.BoolVar(&inFlag.JSON, "ijson", false, "JSON format for input.")
+	flags.BoolVar(&inFlag.YAML, "iyaml", false, "YAML format for input.")
 	flags.BoolVar(&inFlag.TBLN, "itbln", false, "TBLN format for input.")
 	flags.BoolVar(&inFlag.WIDTH, "iwidth", false, "width specification format for input.")
 
@@ -145,6 +146,7 @@ func (cli Cli) Run(args []string) int {
 	flags.BoolVar(&outFlag.JSON, "ojson", false, "JSON format for output.")
 	flags.BoolVar(&outFlag.TBLN, "otbln", false, "TBLN format for output.")
 	flags.BoolVar(&outFlag.JSONL, "ojsonl", false, "JSON lines format for output.")
+	flags.BoolVar(&outFlag.YAML, "oyaml", false, "YAML format for output.")
 
 	if err := flags.Parse(args[1:]); err != nil {
 		log.Printf("ERROR: %s", err)
@@ -477,6 +479,7 @@ type inputFlag struct {
 	CSV   bool
 	LTSV  bool
 	JSON  bool
+	YAML  bool
 	TBLN  bool
 	WIDTH bool
 }
@@ -490,6 +493,8 @@ func inputFormat(i inputFlag) trdsql.Format {
 		return trdsql.LTSV
 	case i.JSON:
 		return trdsql.JSON
+	case i.YAML:
+		return trdsql.YAML
 	case i.TBLN:
 		return trdsql.TBLN
 	case i.WIDTH:
@@ -501,7 +506,7 @@ func inputFormat(i inputFlag) trdsql.Format {
 
 func isInFormat(name string) bool {
 	switch name {
-	case "ig", "icsv", "iltsv", "ijson", "itbln", "iwidth":
+	case "ig", "icsv", "iltsv", "ijson", "iyaml", "itbln", "iwidth":
 		return true
 	}
 	return false
@@ -513,6 +518,7 @@ type outputFlag struct {
 	LTSV  bool
 	JSON  bool
 	JSONL bool
+	YAML  bool
 	TBLN  bool
 	AT    bool
 	MD    bool
@@ -539,6 +545,8 @@ func outputFormat(o outputFlag) trdsql.Format {
 		return trdsql.TBLN
 	case o.JSONL:
 		return trdsql.JSONL
+	case o.YAML:
+		return trdsql.YAML
 	case o.CSV:
 		return trdsql.CSV
 	default:
@@ -548,7 +556,7 @@ func outputFormat(o outputFlag) trdsql.Format {
 
 func isOutFormat(name string) bool {
 	switch name {
-	case "ocsv", "oltsv", "ojson", "ojsonl", "otbln", "oat", "omd", "ovf", "oraw":
+	case "ocsv", "oltsv", "ojson", "ojsonl", "oyaml", "otbln", "oat", "omd", "ovf", "oraw":
 		return true
 	}
 	return false
@@ -580,6 +588,8 @@ func outGuessFormat(fileName string) trdsql.Format {
 			return trdsql.VF
 		case "JSONL":
 			return trdsql.JSONL
+		case "YAML", "YML":
+			return trdsql.YAML
 		}
 		fileName = fileName[0 : len(fileName)-len(dotExt)]
 	}
