@@ -37,6 +37,10 @@ var (
 	ErrNoMatchFound = errors.New("no match found")
 	// ErrNonDefinition is returned when there is no definition.
 	ErrNonDefinition = errors.New("no definition")
+	// ErrInvalidJSON is returned when the JSON is invalid.
+	ErrInvalidJSON = errors.New("invalid JSON")
+	// ErrInvalidYAML is returned when the YAML is invalid.
+	ErrInvalidYAML = errors.New("invalid YAML")
 )
 
 // Importer is the interface import data into the database.
@@ -276,11 +280,6 @@ func GuessOpts(readOpts *ReadOpts, fileName string) (*ReadOpts, string) {
 		}
 	}
 
-	// If the option -ijq is specified, it is assumed to be json(only for guess).
-	if readOpts.InJQuery != "" && readOpts.InFormat == GUESS {
-		readOpts.InFormat = JSON
-	}
-
 	if readOpts.InFormat != GUESS {
 		readOpts.realFormat = readOpts.InFormat
 		return readOpts, fileName
@@ -315,6 +314,8 @@ func guessFormat(fileName string) Format {
 			return LTSV
 		case "JSON", "JSONL":
 			return JSON
+		case "YAML", "YML":
+			return YAML
 		case "TBLN":
 			return TBLN
 		case "WIDTH":
