@@ -133,6 +133,18 @@ func TestTRDSQL_Exec(t *testing.T) {
 			want:    "Orange\nMelon\nApple\n",
 			wantErr: false,
 		},
+		{
+			name:    "testTestYAML",
+			sql:     "SELECT c2 FROM \"" + filepath.Join(dataDir, "test.yaml\""),
+			want:    "Orange\nMelon\nApple\n",
+			wantErr: false,
+		},
+		{
+			name:    "testTestYAMLJQ",
+			sql:     "SELECT name,value FROM " + filepath.Join(dataDir, "sample.yaml::.b.e"),
+			want:    "fred,3\nsam,4\n",
+			wantErr: false,
+		},
 		{
 			name:    "testJoin",
 			sql:     "SELECT j.c1,j.c2,c.c1,c.c2 FROM " + filepath.Join(dataDir, "test.json") + " AS j LEFT JOIN " + filepath.Join(dataDir, "test.csv") + " AS c ON (j.c1 = c.c1)",
@@ -529,6 +541,7 @@ func TestOutFormatRun(t *testing.T) {
 		{format: AT, result: "at"},
 		{format: TBLN, result: "tbln"},
 		{format: JSONL, result: "jsonl"},
+		{format: YAML, result: "yaml"},
 	}
 	sql := "SELECT * FROM " + filepath.Join(dataDir, "test.csv")
 	for _, c := range testFormat {
@@ -756,3 +769,7 @@ func BenchmarkOutput_TBLN(b *testing.B) {
 func BenchmarkOutput_JSON(b *testing.B) {
 	benchmarkFormat(b, JSON)
 }
+
+func BenchmarkOutput_YAML(b *testing.B) {
+	benchmarkFormat(b, YAML)
+}
